# webp2png


## Installation
You can install the package using pip:

```bash
pip install webp2png
```

## Usage

```bash
webp2png -f abc.webp -t abc.png
```
The validate method takes a phone number and an optional country code as arguments. If the phone number is valid, the method returns True. If the phone number is invalid, the method returns False.

